@@ -18,7 +18,7 @@ use Exception::Class (
 );
 use Minions::_Guts;
 
-our $VERSION = '0.000008';
+our $VERSION = '1.000000';
 $VERSION = eval $VERSION;
 
 my $Class_count = 0;
@@ -664,7 +664,7 @@ Minions - Simplifies the creation of loosely coupled object oriented code.
     sub next {
         my ($self) = @_;
 
-        $self->{$__count}++;
+        $self->{$COUNT}++;
     }
 
     1;
