@@ -9,7 +9,7 @@ use Minions::Implementation
 sub next {
     my ($self) = @_;
 
-    $self->{$__count}++;
+    $self->{$COUNT}++;
 }
 
 1;
