@@ -8,18 +8,18 @@ use Minions::Implementation
 
 sub size {
     my ($self) = @_;
-    scalar @{ $self->{$__q} };
+    scalar @{ $self->{$Q} };
 }
 
 sub push {
     my ($self, $val) = @_;
 
-    push @{ $self->{$__q} }, $val;
+    push @{ $self->{$Q} }, $val;
 }
 
 sub pop {
     my ($self) = @_;
-    shift @{ $self->{$__q} };
+    shift @{ $self->{$Q} };
 }
 
 1;
