@@ -8,19 +8,19 @@ use Minions::Implementation
 
 sub size {
     my ($self) = @_;
-    scalar @{ $self->{$__items} };
+    scalar @{ $self->{$ITEMS} };
 }
 
 sub push {
     my ($self, $val) = @_;
 
-    push @{ $self->{$__items} }, $val;
+    push @{ $self->{$ITEMS} }, $val;
 }
 
 sub pop {
     my ($self) = @_;
 
-    shift @{ $self->{$__items} };
+    shift @{ $self->{$ITEMS} };
 }
 
 1;
